@@ -1,15 +1,15 @@
 import json
+import logging
 from abc import ABC, abstractmethod
 from typing import Any, Dict, cast
 
 import boto3
-import logging
-
 from botocore.config import Config
+
 from samtranslator.feature_toggle.dialup import (
     DisabledDialup,
-    ToggleDialup,
     SimpleAccountPercentileDialup,
+    ToggleDialup,
 )
 from samtranslator.metrics.method_decorator import cw_timer
 from samtranslator.utils.constants import BOTO3_CONNECT_TIMEOUT
@@ -93,9 +93,6 @@ class FeatureToggle:
 class FeatureToggleConfigProvider(ABC):
     """Interface for all FeatureToggle config providers"""
 
-    def __init__(self) -> None:
-        pass
-
     @property
     @abstractmethod
     def config(self) -> Dict[str, Any]:
@@ -130,7 +127,7 @@ class FeatureToggleLocalConfigProvider(FeatureToggleConfigProvider):
 class FeatureToggleAppConfigConfigProvider(FeatureToggleConfigProvider):
     """Feature toggle config provider which loads config from AppConfig."""
 
-    @cw_timer(prefix="External", name="AppConfig")  # type: ignore[misc]
+    @cw_timer(prefix="External", name="AppConfig")
     def __init__(self, application_id, environment_id, configuration_profile_id, app_config_client=None):  # type: ignore[no-untyped-def]
         FeatureToggleConfigProvider.__init__(self)
         try:
@@ -142,7 +139,7 @@ class FeatureToggleAppConfigConfigProvider(FeatureToggleConfigProvider):
                 connect_timeout=BOTO3_CONNECT_TIMEOUT, read_timeout=5, retries={"total_max_attempts": 2}
             )
             self.app_config_client = (
-                boto3.client("appconfig", config=client_config) if not app_config_client else app_config_client
+                app_config_client if app_config_client else boto3.client("appconfig", config=client_config)
             )
             response = self.app_config_client.get_configuration(
                 Application=application_id,
