@@ -1,10 +1,12 @@
 import json
+from typing import Any, Dict, Optional
+
 import jsonschema
-from samtranslator import policy_templates_data
-from typing import Dict, Any, Optional
 from jsonschema.exceptions import ValidationError
-from samtranslator.policy_template_processor.template import Template
+
+from samtranslator import policy_templates_data
 from samtranslator.policy_template_processor.exceptions import TemplateNotFoundException
+from samtranslator.policy_template_processor.template import Template
 
 
 class PolicyTemplatesProcessor:
